@@ -29,8 +29,8 @@
 
 /** \file librsync.h
  * Public header for librsync. */
-#ifndef _RSYNC_H
-#  define _RSYNC_H
+#ifndef LIBRSYNC_H
+#  define LIBRSYNC_H
 
 #  include <stdio.h>
 #  include <stdint.h>
@@ -43,7 +43,7 @@ extern "C" {
 
 /** Library version string.
  *
- * \sa \ref versioning */
+ * \sa \ref page_versioning */
 LIBRSYNC_EXPORT extern char const rs_librsync_version[];
 
 typedef uint8_t rs_byte_t;
@@ -312,11 +312,17 @@ LIBRSYNC_EXPORT void rs_sumset_dump(rs_signature_t const *);
  * entry, and suitable to be passed in on a second call, but they don't
  * directly tell you how much output data was produced.
  *
- * Note also that if *#avail_in is nonzero on return, then not all of the input
- * data has been consumed. The caller should either provide more output buffer
- * space and call ::rs_job_iter() again passing the same #next_in and
- * #avail_in, or put the remaining input data into some persistent buffer and
- * call rs_job_iter() with it again when there is more output space.
+ * If the input buffer was large enough, it will be processed directly,
+ * otherwise the data can be copied and accumulated into an internal buffer for
+ * processing. This means using larger buffers can be much more efficient.
+ *
+ * Note also that if #avail_in is nonzero on return, then not all of the input
+ * data has been consumed. This can happen either because it ran out of output
+ * buffer space, or because it processed as much data as possible directly from
+ * the input buffer and needs more input to proceed without copying into
+ * internal buffers. The caller should provide more output buffer space and/or
+ * pack the remaining input data into another buffer with more input before
+ * calling rs_job_iter() again.
  *
  * \sa rs_job_iter() */
 struct rs_buffers_s {
@@ -481,6 +487,9 @@ LIBRSYNC_EXPORT rs_job_t *rs_loadsig_begin(rs_signature_t **);
 LIBRSYNC_EXPORT rs_result rs_build_hash_table(rs_signature_t *sums);
 
 /** Callback used to retrieve parts of the basis file.
+ *
+ * \param opaque The opaque object to execute the callback with. Often the file
+ * to read from.
  *
  * \param pos Position where copying should begin.
  *
@@ -611,4 +620,4 @@ LIBRSYNC_EXPORT rs_result rs_patch_file(FILE *basis_file, FILE *delta_file,
 }                               /* extern "C" */
 #  endif
 
-#endif                          /* !_RSYNC_H */
+#endif                          /* !LIBRSYNC_H */
